const lightCodeTheme = require("prism-react-renderer/themes/github");
const darkCodeTheme = require("prism-react-renderer/themes/dracula");

/** @type {import('@docusaurus/types').DocusaurusConfig} */
module.exports = {
  title: "Simplifiez-vous le code",
  tagline: "",
  url: process.env.DOCUSAURUS_URL || "https://froggit.fr",
  baseUrl: process.env.DOCUSAURUS_BASEURL || "/",
  onBrokenLinks: "throw",
  onBrokenMarkdownLinks: "warn",
  favicon: "img/favicon/favicon.ico",
  organizationName: "froggit/www", // Usually your GitHub org/user name.
  projectName: "froggit.fr", // Usually your repo name.
  themeConfig: {
    metadata: [{
      name: "description", content: "Collaborez autour du code sur la première plateforme intégrée DevOps Made in France. Avec Froggit, sécurisez vos données, améliorez vos performances et protégez enfin la planète. Nous hébergeons et infogérons GitLab et Mattermost pour vous en France, pas de Cloud Act avec nous !"
    },
    {
      name: "title", content: "Simplifiez-vous le code..."
    }],
    navbar: {
      title: "",
      logo: {
        alt: "Froggit Logo",
        src: "img/theme/froggit-logo.png",
      },
      items: [      
        {label: "Fonctionnalités", position: "left", to: "/#features", exact: true},
        {label: "FAQ", position: "left", to: "/faq"},
        {
          type: "dropdown",
          label: "Tarifs",
          position: "left",
          items: [
            {
              label: "Offre SaaS",
              to: "/tarifs"
            },
            {
              label: "Offre Dédiée",
              to: "/dedie"
            },
          ],
        },
        {label: "Doc", position: "left", type: "doc", docId: "intro", },
        {
          type: "dropdown",
          label: "🎓 Apprendre",
          position: "left",
          items: [
            {
              label: "🎁 Antisèche et Communauté git",
              to: "/communaute",
            },
            {
              label: "L'accélérateur : mentorat de groupe",
              to: "/accelerateur-gitlab",
            },
          ],
        },
        {
          label: "👤 Connexion",
          position: "right",
          href: "https://lab.frogg.it/users/sign_in",
        },
        {label: "S'enregistrer", position: "right", to: "/tarifs"},
        {
          type: "dropdown",
          label: "Les services",
          position: "right",
          items: [
            {
              label: "Le Lab 🧪",
              href: "https://lab.frogg.it/",
            },
            {
              label: "Le Chat 💬",
              href: "https://chat.froggit.fr/",
            },
            {
              label: "Status ✔",
              href: "https://status.froggit.fr/",
            },
          ],
        },
      ],
    },
    footer: {
      style: "dark",
      links: [
        {
          title: "Pourquoi Froggit ?",
          items: [
            {
              label: "🔐 Ton code source est-il en sécurité?",
              href: "https://lydra.fr/es-2-ton-code-source-est-il-vraiment-en-securite/",
            },
            {
              label: "La souveraineté numérique",
              href: "https://lydra.fr/category/souverainete-numerique/",
            },
            {
              label: "git késako ?",
              href: "https://github.com/git-guides/",
            },
          ],
        },
        {
          title: "Offres et Tarifs",
          items: [
            {
              label: "Offre SaaS",
              to: "/tarifs",
            },
            {
              label: "Offre Dédiée",
              to: "/dedie",
            },
          ]
        },
        {
          title: "Support",
          items: [
            {
              label: "Contact",
              to: "/contacts",
            },
            {
              html: `
              <a href='https://status.froggit.fr/' target='_blank'>
                <img style="margin-top: 0.3rem" src="https://status.lydra.fr/api/badge/5/uptime/720?label=Le%20Lab%20🧪" />
              </a>`,
            },
            {
              html: `
              <a href='https://status.froggit.fr/' target='_blank'>
                <img style="margin-top: 0.3rem" src="https://status.lydra.fr/api/badge/11/uptime/720?label=Les%20Pages%20🔖" />
              </a>`,
            },
            {
              html: `
              <a href='https://status.froggit.fr/' target='_blank'>
                <img style="margin-top: 0.3rem" src="https://status.lydra.fr/api/badge/10/uptime/720?label=Le%20Chat%20💬" />
              </a>`,
            },
            {
              html: `
              <a href='https://status.froggit.fr/' target='_blank'>
                <img style="margin-top: 0.3rem" src="https://status.lydra.fr/api/badge/83/uptime/720?label=La%20communauté%20🍺" />
              </a>`,
            },
          ],
        },
        {
          title: "Société",
          items: [
            {
              label: "À propos",
              href: "https://lydra.fr",
            },
            {
              label: "Équipe",
              href: "https://lydra.fr/#team",
            },
            {
              label: "Sous-traitants",
              to: "/sous-traitants",
            },
            {
              label: "Mentions légales",
              to: "/mentions-legales",
            },
            {
              label: "📜 CGV",
              to: "/CGV",
            },
            {
              label: "📃 CGU",
              to: "/CGU",
            },
            {
              label: "Politique de confidentialité",
              to: "/confidentialite",
            },
            {
              label: "Kit presse",
              href: "https://cloud.lydra.fr/s/k6y5s76La4M3fKn",

            }
          ],
        },
      ],
      // eslint-disable-next-line quotes
      copyright: `Lydra © ${new Date().getFullYear()}` +"<br/>"+ `Froggit est fièrement fabriqué avec ❤️ par <a href="http://lydra.fr/">Lydra</a> avec des Logiciels Libres et hébergé en 🇫🇷 chez <a href="https://www.scaleway.fr/">Scaleway</a>` +"<br/>"+ `Construit avec <a href="https://docusaurus.io/fr">Docusaurus</a>`,
    },
    prism: {
      theme: lightCodeTheme,
      darkTheme: darkCodeTheme,
    },
  },
  presets: [
    [
      "@docusaurus/preset-classic",
      {
        docs: {
          sidebarPath: require.resolve("./sidebars.js"),
          // Please change this to your repo.
          editUrl:
            "https://lab.frogg.it/froggit/www/froggit.fr/-/tree/master",
        },
        blog: {
          showReadingTime: true,
          // Please change this to your repo.
          editUrl:
            "https://lab.frogg.it/froggit/www/froggit.fr/-/tree/master/blog/",
        },
        theme: {
          customCss: require.resolve("./src/css/custom.css"),
        },
      },
    ],
  ],
  plugins: [
    [
      // https://github.com/gabrielcsapo/docusaurus-plugin-matomo#usage
      require.resolve("@gabrielcsapo/docusaurus-plugin-matomo"),
      {
        siteId: "5",
        matomoUrl: "https://stats.esprit-libre-conseil.com",
        siteUrl: process.env.DOCUSAURUS_URL || "https://froggit.fr",
        matomoPhpScript: "m.php",
        matomoJsScript: "m.js",
        enableJSErrorTracking: true,
      },
    ],
  ],
};
