/* eslint react/prop-types: 0 */
import React from "react";
import Slider from "react-slick";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import useBaseUrl from "@docusaurus/useBaseUrl";

function Logo({img, svg, alt}) {
  if (img) {
    return (
      <> 
        <img src={useBaseUrl(img)} alt={alt} className="carousel-img" />
      </>
    );
  }
  else if (svg) {
    return (
      <svg alt={alt}>
        {svg}
      </svg>
    );
  }
}

function CarouselElement({name, img, svg, link, alt}) {
  return (
    <div className="carousel-box">
      {(() => {
        if (link) {
          return (
            <a href={link} target="_blank" rel="noopener noreferrer">
              <Logo img={img} svg={svg} alt={alt}/>
            </a>
          );
        }
        else {
          return (
            <Logo img={img} svg={svg} alt={alt}/>
          );         
        }
      })()}   
      {(() => {
        if (name) {
          return (
            <h6 className="carousel-title">{name}</h6>
          ); 
        }
      })()}
    </div>
  );
}

export default function Carousel(props) {
  const list = props.list;
  //https://react-slick.neostack.com/docs/api/
  const settings = {
    infinite: true,
    easing: "linear",
    slidesToShow: 2,
    slidesToScroll: 1,
    arrows: false,
    autoplay: true,
    speed: 3000,
    draggable: false,
    swipeToSlide: false,
    autoplaySpeed: 3000,
    variableWidth: true,
    centerMode: true,
    pauseOnHover: true,
    cssEase: "linear"
  };

  return (
    <div>
      <Slider {...settings}>
        {list.map((props, idx) => (
          <CarouselElement key={idx} {...props} />
        ))}
      </Slider>
    </div>
  );
}
